import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const { email, motDePasse } = await request.json();

    // validation des champs saisis
    if (!email || !motDePasse) {
      return NextResponse.json(
        { success: false, message: 'Email et mot de passe sont obligatoire' },
        { status: 400 }
      );
    }

    const loginResponse = await fetch('http://localhost:5080/api/utilisateurs/login', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json',
        'Accept': '*/*'
      },
      body: JSON.stringify({ email, motDePasse }),
    });

    const loginData = await loginResponse.json();

    if (!loginResponse.ok) {
      return NextResponse.json(
        { success: false, message: loginData.message || 'Identifiants invalides' },
        { status: loginResponse.status }
      );
    }

    // créetion d'une réponse avec le cookie d'authentification
    const response = NextResponse.json(loginData);

    // définition du cookie contenant le token JWT
    response.cookies.set({
      name: 'admin_token',
      value: loginData.token,
      httpOnly: true,
      secure: process.env.NODE_ENV === 'production',
      sameSite: 'strict',
      path: '/',
      // expiration du cookie 2 jours
      maxAge: 2 * 24 * 60 * 60
    });

    return response;
  } catch (error) {
    console.error('Erreur lors de la connexion:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur de serveur' },
      { status: 500 }
    );
  }
}