import { NextRequest, NextResponse } from 'next/server';

export async function GET(request: NextRequest) {
  try {
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }

    // route qui permet de vérifier la validité du token
    const apiResponse = await fetch('http://localhost:5080/api/utilisateurs/me', {
      headers: {
        'Authorization': `Bearer ${token}`,
        'Accept': '*/*'
      }
    });
    
    if (!apiResponse.ok) {
      // si le retour de la réponse n'est pas correct on supprimme le cookie
      const nextResponse = NextResponse.json(
        { success: false, message: 'Session invalide' },
        { status: 401 }
      );
      
      //  suprpession du cookie
      nextResponse.cookies.set({
        name: 'admin_token',
        value: '',
        expires: new Date(0),
        path: '/',
      });
      
      return nextResponse;
    }

    const userData = await apiResponse.json();
    
    // vérificationm que le role est dans la réponse de l'api
    if (userData.data && !userData.data.roleNom) {
      console.error(`le rôle ou les informations de l'uttilisateur ne sont pas présentes`);
    }
    
    return NextResponse.json({ 
      success: true, 
      user: userData.data 
    });
  } catch (error) {
    console.error('Erreur de vérification de session:', error);
    
    // erreur de conexion : suppression du cookie
    const nextResponse = NextResponse.json(
      { success: false, message: 'Erreur de vérification de session' },
      { status: 500 }
    );
    
    nextResponse.cookies.set({
      name: 'admin_token',
      value: '',
      expires: new Date(0),
      path: '/',
    });
    
    return nextResponse;
  }
}