import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const { id } = await request.json();
    
    if (!id) {
      return NextResponse.json(
        { success: false, message: 'ID du salarié requis' },
        { status: 400 }
      );
    }
    
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }
    
    const response = await fetch(`http://localhost:5080/api/salaries/${id}`, {
      method: 'DELETE',
      headers: {
        'Authorization': `Bearer ${token}`,
        'Accept': '*/*'
      }
    });
    
    if (!response.ok) {
      const responseText = await response.text();
      return NextResponse.json(
        { success: false, message: `Erreur ${response.status}: ${responseText}` },
        { status: response.status }
      );
    }
    
    return NextResponse.json(
      { success: true, message: 'Salarié supprimé avec succès' }
    );
  } catch (error) {
    console.error('Erreur lors de la suppression du salarié:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}