import { NextRequest, NextResponse } from 'next/server';

export async function POST(request: NextRequest) {
  try {
    const { id } = await request.json();
    
    if (!id) {
      return NextResponse.json(
        { success: false, message: 'ID du service requis' },
        { status: 400 }
      );
    }

    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }
    
    const response = await fetch(`http://localhost:5080/api/services/${id}`, {
      method: 'DELETE',
      headers: {
        'Authorization': `Bearer ${token}`,
        'Accept': '*/*'
      }
    });
    
    console.log(`Statut de la réponse du backend: ${response.status}`);
    
    if (!response.ok) {
      try {
        const errorData = await response.json();
        
        // vérification que l'erreur concerne des salariés affectés à ce service
        if (errorData.message && errorData.message.includes("il n'est pas possible de supprimer ce service car des salariés y sont liés")) {
          return NextResponse.json(
            { 
              success: false, 
              message: errorData.message,
              isDependencyError: true
            },
            { status: 400 }
          );
        }
        
        return NextResponse.json(
          { success: false, message: errorData.message || `Erreur ${response.status}` },
          { status: response.status }
        );
      } catch {
        // sila réponse n'est pas au format JSON, tenter de récupérer le texte
        const responseText = await response.text();
        console.error(`Erreur du backend: ${responseText}`);
        return NextResponse.json(
          { success: false, message: `Erreur ${response.status}: ${responseText}` },
          { status: response.status }
        );
      }
    }
    
    return NextResponse.json(
      { success: true, message: 'Service supprimé avec succès' }
    );
  } catch (error) {
    console.error('Exception lors de la suppression:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}