import { NextRequest, NextResponse } from 'next/server';
import { fetchSitesFromBackend, createSiteInBackend, updateSiteInBackend } from '@/app/lib/backend-api';

// r'épurératuio nde tous les sites
export async function GET(request: NextRequest) {
  try { 
    // récupère les informations de la pagination 
    const { searchParams } = new URL(request.url);
    const pageNumber = parseInt(searchParams.get('pageNumber') || '1');
    const pageSize = parseInt(searchParams.get('pageSize') || '25');
    
    const data = await fetchSitesFromBackend(pageNumber, pageSize);
    
    return NextResponse.json(data);
  } catch (error) {
    console.error('Erreur lors de la récupération des sites:', error);
    return NextResponse.json(
      { 
        data: [],
        pageNumber: 1,
        pageSize: 25,
        totalPages: 0,
        totalCount: 0,
        hasPreviousPage: false,
        hasNextPage: false
      },
      { status: 500 }
    );
  }
}

// creatiopn d'un site
export async function POST(request: NextRequest) {
  try {
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: `Vous n'êtes pas connecté` },
        { status: 401 }
      );
    }
    

    const originalBody = await request.json();
    
    // vérific ation que la ville soit présente
    if (!originalBody.ville) {
      return NextResponse.json(
        { success: false, message: 'La ville du site est obligatoire' },
        { status: 400 }
      );
    }
    
    const data = await createSiteInBackend(token, originalBody.ville);
    
    return NextResponse.json({ success: true, data }, { status: 201 });
  } catch (error) {
    console.error('Erreur lors de la création du site:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}

// mise à jour d'un site
export async function PUT(request: NextRequest) {
  try {
    const token = request.cookies.get('admin_token')?.value;
    
    if (!token) {
      return NextResponse.json(
        { success: false, message: 'Non authentifié' },
        { status: 401 }
      );
    }
    
    const originalBody = await request.json();
    
    // vérificatio nde l'id et de la ville
    if (!originalBody.id) {
      return NextResponse.json(
        { success: false, message: `L'id est obligatoire`},
        { status: 400 }
      );
    }
    
    if (!originalBody.ville) {
      return NextResponse.json(
        { success: false, message: `La ville du site est obligatoire`},
        { status: 400 }
      );
    }
    
    const data = await updateSiteInBackend(token, originalBody.id, originalBody.ville);
    
    return NextResponse.json({ success: true, data });
  } catch (error) {
    console.error('Erreur lors de la mise à jour du site:', error);
    return NextResponse.json(
      { success: false, message: 'Erreur serveur', error: String(error) },
      { status: 500 }
    );
  }
}