// hooks/useKeyboardShortcut.ts
'use client';

import { useEffect } from 'react';
import { useRouter } from 'next/navigation';
import { useAuth } from '@/components/AuthProvider';

export function useAdminKeyboardShortcut() {
  const router = useRouter();
  const { user, isLoading } = useAuth();
  
  useEffect(() => {
    const handleKeyDown = async (event: KeyboardEvent) => {  
      // Ctrl+Alt+Shift pour accéder à l'admin
      if (event.ctrlKey && event.altKey && event.shiftKey) {
        if (user) {
          router.push('/admin/dashboard');
        } else {
          await fetch('/api/admin/set-access-cookie', { method: 'POST' });
          router.push('/admin/login');
        }
      }
    };

    if (!isLoading) {
      window.addEventListener('keydown', handleKeyDown);
    }
    
    return () => {
      window.removeEventListener('keydown', handleKeyDown);
    };

  }, [router, user, isLoading]);
}