'use client'

import Link from 'next/link';
import { useState, useEffect } from 'react';
import MobileMenu from '@/components/MobileMenu';
import { useAuth } from '@/components/AuthProvider';

const Header = () => {
  const [scrolled, setScrolled] = useState(false);
  const [isMobileMenuOpen, setIsMobileMenuOpen] = useState(false);
  const { user, logout } = useAuth();
  
  const isAdmin = !!(user && user.roleNom === 'admin');
  
  useEffect(() => {
    const handleScroll = () => {
      setScrolled(window.scrollY > 10);
    };
    
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, []);

  const toggleMobileMenu = () => {
    setIsMobileMenuOpen(!isMobileMenuOpen);
  };

  const closeMobileMenu = () => {
    setIsMobileMenuOpen(false);
  };

  const handleLogout = async () => {
    await logout();
  };

  return (
    <>
      <header className={`sticky top-0 z-50 ${isAdmin ? 'bg-primary/10' : 'bg-background/80'} backdrop-blur-md border-b border-border transition-all duration-300 ${scrolled ? 'shadow-md py-2' : 'py-4'}`}>
        <div className="container mx-auto px-4 flex justify-between items-center">
          {/* Logo à gauche */}
          <Link href={isAdmin ? '/admin/dashboard' : '/'} className="text-2xl font-bold bg-gradient-to-r from-primary to-accent bg-clip-text hover:scale-105 transition-transform flex items-center">
            <span>Annuaire CESI</span>
            {isAdmin && (
              <span className="ml-2 text-xs px-2 py-1 bg-primary text-white rounded-md">
                ADMIN
              </span>
            )}
          </Link>
          
          <nav className="hidden md:flex space-x-6">
            {isAdmin ? (
              // liens admin
              <>
                <Link href="/admin/dashboard" className="text-foreground/80 hover:text-primary transition-colors">
                  Dashboard
                </Link>
                <Link href="/admin/salaries" className="text-foreground/80 hover:text-primary transition-colors">
                  Salariés
                </Link>
                <Link href="/admin/services" className="text-foreground/80 hover:text-primary transition-colors">
                  Services
                </Link>
                <Link href="/admin/sites" className="text-foreground/80 hover:text-primary transition-colors">
                  Sites
                </Link>
                <button 
                  onClick={handleLogout}
                  className="text-red-600 hover:text-red-800 transition-colors"
                >
                  Déconnexion
                </button>
              </>
            ) : (
              // visu d'un visiteur
              <Link href="/" className="text-foreground/80 hover:text-primary transition-colors">
                Accueil
              </Link>
            )}
          </nav>
          
          {/* boution hamburger responsiive*/}
          <button 
            className="md:hidden text-foreground hover:text-primary transition-colors p-1 rounded-md"
            onClick={toggleMobileMenu}
            aria-label="Menu"
          >
            <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" strokeWidth={1.5} stroke="currentColor" className="w-6 h-6">
              <path strokeLinecap="round" strokeLinejoin="round" d="M3.75 6.75h16.5M3.75 12h16.5m-16.5 5.25h16.5" />
            </svg>
          </button>
        </div>
      </header>
      
      <MobileMenu 
        isOpen={isMobileMenuOpen} 
        onClose={closeMobileMenu} 
        isAdmin={isAdmin}
        onLogout={handleLogout}
      />
    </>
  );
};

export default Header;