'use client';

import { useEffect, useState } from 'react';
import { useRouter } from 'next/navigation';
import { useAuth } from './AuthProvider';

// composant qui autorise l'affichage selon les informations de l'utilisatuer : si il a le role admin authorise l'affichage
export default function ProtectedRoute({ 
  children,
  adminOnly = true
}: { 
  children: React.ReactNode,
  adminOnly?: boolean
}) {
  const { user, isLoading } = useAuth();
  const router = useRouter();
  const [isAuthorized, setIsAuthorized] = useState(false);


  useEffect(() => {
    if (!isLoading) {
      if (!user) {
        router.push('/admin/login');
      } else if (adminOnly && (!user.roleNom || user.roleNom !== 'admin')) {
        router.push('/unauthorized');
      } else {
        setIsAuthorized(true);
      }
    }
  }, [user, isLoading, router, adminOnly]);

  // affichage  d'un loader pendant la vérification ou le chargement
  if (isLoading || (!isAuthorized && user)) {
    return (
      <div className="min-h-screen flex items-center justify-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-primary"></div>
      </div>
    );
  }

  // si l'utilisateur n'est pas autorisé on affiche rienm
  if (!isLoading && (!user || (adminOnly && (!user.roleNom || user.roleNom !== 'admin')))) {
    return null;
  }

  // affichage du contenu si l'utilisateur est autorisé
  return <>{children}</>;
}