'use client';
import { useState, useEffect } from 'react';
import { X } from 'lucide-react';

interface SiteModalProps {
  site: { id: number; ville: string } | null;
  onClose: () => void;
  onSave: (site: { ville: string }) => void;
}

export default function SiteModal({ site, onClose, onSave }: SiteModalProps) {
  const [ville, setVille] = useState('');
  const [error, setError] = useState('');

  useEffect(() => {
    if (site) {
      setVille(site.ville);
    }
  }, [site]);

  const handleSubmit = (e: React.FormEvent) => {
    e.preventDefault();
    
    // Validation
    if (!ville.trim()) {
      setError('La ville du site est requise');
      return;
    }
    
    onSave({ ville });
  };

  return (
    <div className="fixed inset-0 z-50 bg-black/50 flex items-center justify-center p-4">
      <div className="bg-card rounded-lg shadow-lg max-w-md w-full overflow-hidden  backdrop-blur-md">
        <div className="flex justify-between items-center px-6 py-4 border-b border-border">
          <h2 className="text-xl font-semibold">
            {site ? 'Modifier le site' : 'Ajouter un site'}
          </h2>
          <button 
            onClick={onClose}
            className="text-muted-foreground hover:text-foreground"
          >
            <X size={24} />
          </button>
        </div>
        
        <form onSubmit={handleSubmit} className="p-6">
          {error && (
            <div className="mb-4 p-3 bg-red-100 text-red-700 rounded-md">
              {error}
            </div>
          )}
          
          <div className="mb-4">
            <label htmlFor="ville" className="block text-sm font-medium mb-2">
              Ville
            </label>
            <input
              type="text"
              id="ville"
              value={ville}
              onChange={(e) => setVille(e.target.value)}
              className="w-full px-3 py-2 border border-border rounded-md focus:outline-none focus:ring-2 focus:ring-primary"
              placeholder="Ville du site"
            />
          </div>
          
          <div className="flex justify-end gap-3 mt-6">
            <button
              type="button"
              onClick={onClose}
              className="px-4 py-2 border border-border rounded-md hover:bg-muted transition-colors"
            >
              Annuler
            </button>
            <button
              type="submit"
              className="px-4 py-2 bg-primary text-white rounded-md hover:bg-primary-dark transition-colors"
            >
              Enregistrer
            </button>
          </div>
        </form>
      </div>
    </div>
  );
}