// app/utils/api.ts
import { Salarie } from '@/types/Salarie';
import { Service } from '@/types/Service';
import { Site } from '@/types/Site';
import { PaginatedResponse } from '@/types/PaginatedResponse';

export const fetchSalaries = async (
  pageNumber: number = 1,
  pageSize: number = 25,
  searchTerm: string = ''
): Promise<PaginatedResponse<Salarie>> => {
  try {
    const params = new URLSearchParams();
    params.append('pageNumber', pageNumber.toString());
    params.append('pageSize', pageSize.toString());

    const url = searchTerm
      ? `/api/salaries/search?${params.toString()}&searchTerm=${encodeURIComponent(searchTerm)}`
      : `/api/salaries/all?${params.toString()}`;

    const response = await fetch(url);
    if (!response.ok) throw new Error('Erreur lors de la récupération des salariés');
    return await response.json();
  } catch (error) {
    console.error('Erreur lors de la récupération des salariés : ', error);

    return {
      data: [],
      totalPages: 0,
      pageNumber: pageNumber,
      pageSize: pageSize,
      totalCount: 0
    };
  }
};

export const fetchSites = async (
  pageNumber: number = 1, 
  pageSize: number = 25
): Promise<PaginatedResponse<Site>> => {
  const response = await fetch(`/api/sites?pageNumber=${pageNumber}&pageSize=${pageSize}`);
  if (!response.ok) throw new Error('Erreur lors de la récupération des sites');
  const result = await response.json();
  return result;
};

export const fetchServices = async (
  pageNumber: number = 1, 
  pageSize: number = 25
): Promise<PaginatedResponse<Service>> => {
  const response = await fetch(`/api/services?pageNumber=${pageNumber}&pageSize=${pageSize}`);
  if (!response.ok) throw new Error('Erreur lors de la récupération des services');
  const result = await response.json();
  return result;
};

export const fetchSalariesBySite = async (
  siteId: number,
  pageNumber: number = 1,
  pageSize: number = 25
): Promise<PaginatedResponse<Salarie>> => {
  const params = new URLSearchParams();
  params.append('pageNumber', pageNumber.toString());
  params.append('pageSize', pageSize.toString());

  const response = await fetch(`/api/salaries/site/${siteId}?${params.toString()}`);
  if (!response.ok) throw new Error('Erreur lors de la récupération des salariés par site');
  const result = await response.json();
  return result;
};

export const fetchSalariesByService = async (
  serviceId: number,
  pageNumber: number = 1,
  pageSize: number = 25
): Promise<PaginatedResponse<Salarie>> => {
  const params = new URLSearchParams();
  params.append('pageNumber', pageNumber.toString());
  params.append('pageSize', pageSize.toString());

  const response = await fetch(`/api/salaries/service/${serviceId}?${params.toString()}`);
  if (!response.ok) throw new Error('Erreur lors de la récupération des salariés par service');
  const result = await response.json();
  return result;
};